pilas

Package pilas |
[hide private]
[frames] | no frames]

# Package pilas

source code

# Módulo pilas

Pilas es una biblioteca para facilitar el desarrollo de videojuegos. Es útil para programadores principiantes o para el desarrollo de juegos casuales.

Este módulo contiene las funciones principales para iniciar y ejecutar la biblioteca.

Submodules | [hide private]
pilas.actores: El módulo actores contiene una serie de clases para representar personajes de videojuegos. pilas.actores.aceituna pilas.actores.actor pilas.actores.animacion pilas.actores.animado pilas.actores.banana pilas.actores.bomba pilas.actores.boton pilas.actores.caja pilas.actores.cooperativista pilas.actores.cursordisparo pilas.actores.dialogo pilas.actores.ejes pilas.actores.energia pilas.actores.estrella pilas.actores.explosion pilas.actores.fantasma pilas.actores.globo pilas.actores.globoelegir pilas.actores.humo pilas.actores.mano pilas.actores.mapa pilas.actores.mapatiled pilas.actores.martian pilas.actores.menu pilas.actores.moneda pilas.actores.mono pilas.actores.nave pilas.actores.navekids pilas.actores.opcion pilas.actores.ovni pilas.actores.pacman pilas.actores.pausa pilas.actores.pelota pilas.actores.personajes_rpg pilas.actores.piedra pilas.actores.pingu pilas.actores.pizarra pilas.actores.proyectil pilas.actores.puntaje pilas.actores.sonido pilas.actores.temporizador pilas.actores.texto pilas.actores.texto_inferior pilas.actores.torreta pilas.actores.tortuga pilas.actores.utils pilas.actores.zanahoria pilas.asistente pilas.asistente_base pilas.atajos pilas.camara pilas.colisiones pilas.colores pilas.comportamientos pilas.control: pilas.demos pilas.demos.piezas pilas.depurador pilas.descargar pilas.ejemplos pilas.ejemplos.cargador pilas.ejemplos.syntax pilas.ejemplos.ui pilas.escena pilas.escena.escena_base pilas.escena.escena_normal pilas.escena.gestor pilas.escenas pilas.estudiante pilas.evento: pilas.fisica pilas.fondos pilas.fps pilas.grupo pilas.habilidades pilas.imagenes pilas.interfaz pilas.interfaz.base_interfaz pilas.interfaz.boton pilas.interfaz.deslizador pilas.interfaz.ingreso_de_texto pilas.interfaz.lista_seleccion pilas.interfaz.selector pilas.interpolaciones pilas.interprete pilas.interprete_base pilas.lanzador pilas.lanzador_base pilas.lienzo pilas.motores pilas.motores.motor_qt pilas.mundo pilas.mundo' pilas.municion pilas.musica pilas.pilasversion pilas.pytweener pilas.red pilas.simbolos pilas.sonidos pilas.tareas pilas.utils pilas.ventana pilas.video: import video import pilas pilas.video.video: import pilas try: import opencv from opencv import highgui except ImportError: opencv = None pilas.video.webcam: import pilas try: import Image import opencv from opencv import highgui pilas.widget_log

Functions | [hide private]
_crear_motor(usar_motor, permitir_depuracion, audio) Genera instancia del motor multimedia en base a un nombre. | source code
_usa_interprete_lanas() Retorna True si se ha iniciado pilas desde lanas | source code
abrir_asistente() Abre una ventana que permite iniciar pilas graficamente. | source code
abrir_cargador() Abre un cargador de ejemplos con varios códigos de prueba. | source code
abrir_interprete(parent=None, do_raise=False) Abre un intérprete interactivo de python con una ventana. | source code
almacenar_escena(escena) | source code
avisar(mensaje, retraso=5) Emite un mensaje en la ventana principal. | source code
cambiar_escena(escena) | source code
ejecutar(ignorar_errores=False) Pone en funcionamiento las actualizaciones y dibujado. | source code
escena_actual() | source code
esta_inicializada() Indica si la biblioteca pilas ha sido inicializada con pilas.iniciar() | source code
iniciar(ancho=640, alto=480, titulo=`'``Pilas``'`, usar_motor=`'``qtgl``'`, rendimiento=60, modo=`'``detectar``'`, gravedad=`(`0`,` -90`)`, pantalla_completa=False, permitir_depuracion=True, audio=`'``phonon``'`) Inicia la ventana principal del juego con algunos detalles de funcionamiento. | source code
iniciar_con_lanzador(ancho=640, alto=480, titulo=`'``Pilas``'`, rendimiento=60, modo=`'``detectar``'`, gravedad=`(`0`,` -90`)`, imagen=`'``asistente.png``'`, permitir_depuracion=True) Identica a la función iniciar, solo que permite al usuario seleccionar el motor multimedia y el modo de video a utilizar. | source code
log(*parametros) | source code
recuperar_escena() | source code
reiniciar() Elimina todos los actores y vuelve al estado inicial. | source code
terminar() Finaliza la ejecución de pilas y cierra la ventana principal. | source code
ver(objeto, imprimir=True, retornar=False) Imprime en pantalla el codigo fuente asociado a un objeto. | source code
version() Retorna el número de version de pilas. | source code

Variables | [hide private]
| __doc__ = ``...``
| __package__ = ``'``pilas``'``
| bg = `None` hash(x)
| eventos = `ProxyEventos()`

Function Details | [hide private]

### _crear_motor(usar_motor, permitir_depuracion, audio) | source code
Genera instancia del motor multimedia en base a un nombre. Esta es una función interna y no debe ser ejecutada excepto por el mismo motor pilas.

### abrir_asistente() | source code
Abre una ventana que permite iniciar pilas graficamente. Las opciones que ofrece son "leer el manual" (si esta disponible), "abrir un interprete", "explorar los ejemplos" etc. Esta ventana se ha diseñado para mostrarse a los nuevos usuarios de pilas, por ejemplo cuando eligen abrir pilas desde el icono principal.

### abrir_cargador() | source code
Abre un cargador de ejemplos con varios códigos de prueba. Ejemplo:
    >>> pilas.abrir_cargador()
El cargador de ejemplos se ve de esta forma: .. image:: images/cargador.png

### abrir_interprete(parent=None, do_raise=False) | source code
Abre un intérprete interactivo de python con una ventana. Esta función se ejecuta cuando un usuario escribe:
       pilas -i
en una consola del sistema.

### avisar(mensaje, retraso=5) | source code
Emite un mensaje en la ventana principal. Este mensaje aparecerá en la parte inferior de la pantalla durante 5 segundo, por ejemplo:
    >>> pilas.avisar("Use la tecla <esc> para terminar el programa")

### ejecutar(ignorar_errores=False) | source code
Pone en funcionamiento las actualizaciones y dibujado. Esta función es necesaria cuando se crea un juego en modo ``no-interactivo``.

### iniciar(ancho=640, alto=480, titulo=`'``Pilas``'`, usar_motor=`'``qtgl``'`, rendimiento=60, modo=`'``detectar``'`, gravedad=`(`0`,` -90`)`, pantalla_completa=False, permitir_depuracion=True, audio=`'``phonon``'`) | source code
Inicia la ventana principal del juego con algunos detalles de funcionamiento. Ejemplo de invocación:
    >>> pilas.iniciar(ancho=320, alto=240)
.. image:: images/iniciar_320_240.png Parámetros: :ancho: el tamaño en pixels para la ventana. :alto: el tamaño en pixels para la ventana. :titulo: el titulo a mostrar en la ventana. :usar_motor: el motor multimedia a utilizar, puede ser 'qt', 'qtgl', 'qtsugar' o 'qtsugargl'. :rendimiento: cantidad de cuadros por segundo a mostrar. :modo: si se utiliza modo interactivo o no. :gravedad: el vector de aceleracion para la simulacion de fisica. :pantalla_completa: si debe usar pantalla completa o no. :permitir_depuracion: si se desea tener habilidatas las funciones de depuracion de las teclas F5 a F12

### iniciar_con_lanzador(ancho=640, alto=480, titulo=`'``Pilas``'`, rendimiento=60, modo=`'``detectar``'`, gravedad=`(`0`,` -90`)`, imagen=`'``asistente.png``'`, permitir_depuracion=True) | source code
Identica a la función iniciar, solo que permite al usuario seleccionar el motor multimedia y el modo de video a utilizar. Esta función es útil cuando se quiere distribuir un juego y no se conoce exáctamente el equipo del usuario.

Variables Details | [hide private]

  ### __doc__ Value:
      """
      M\xc3\xb3dulo pilas
      ============

      Pilas es una biblioteca para facilitar el desarrollo
      de videojuegos. Es \xc3\xbatil para programadores
      principiantes o para el desarrollo de juegos casuales.

      ...